/*  BSD-License:

Copyright (c) 2010 by Nils Springob, nicai-systems, Germany

All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  * Neither the name nicai-systems nor the names of its contributors may be
    used to endorse or promote products derived from this software without
    specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

/*! @file    iodefs_nibobee.h
 *  @brief   Zuordnung der physikalischen Pins zu symbolischen Namen
 *  @author  Nils Springob (nils@nicai-systems.de)
 *  @date    2010-03-28
 */

extern volatile uint8_t io_port_x;
extern volatile uint8_t io_ddr_x;

#define PORTX io_port_x
#define DDRX io_ddr_x

/*! LED group */
#define IO_LEDS_PORT  PORTX
#define IO_LEDS_MASK  0xf0
#define IO_LEDS_DDR   DDRX
#define IO_LEDS_BIT_Y1 7
#define IO_LEDS_BIT_Y2 6
#define IO_LEDS_BIT_Y3 5
#define IO_LEDS_BIT_Y4 4


/*! Button group */
#define IO_SENS_PORT  PORTX
#define IO_SENS_PIN   PIND
#define IO_SENS_MASK  0x0f
#define IO_SENS_DDR   DDRX
#define IO_SENS_BIT_BTN4 0
#define IO_SENS_BIT_BTN3 1
#define IO_SENS_BIT_BTN2 2
#define IO_SENS_BIT_BTN1 3


/*! Key */
#define IO_KEY_PORT  PORTB
#define IO_KEY_PIN   PINB
#define IO_KEY_BIT   0
#define IO_KEY_DDR   DDRB



/*! I2C SDA */
#define IO_I2C_SDA_PORT  PORTC
#define IO_I2C_SDA_PIN   PINC
#define IO_I2C_SDA_BIT   4
#define IO_I2C_SDA_DDR   DDRC


/*! I2C SCL */
#define IO_I2C_SCL_PORT  PORTC
#define IO_I2C_SCL_PIN   PINC
#define IO_I2C_SCL_BIT   5
#define IO_I2C_SCL_DDR   DDRC





/*! Display register select (D/I) */
#define IO_DISPLAY_RS       IO_DISPLAY_RS
#define IO_DISPLAY_RS_PORT  PORTB
#define IO_DISPLAY_RS_BIT   4
#define IO_DISPLAY_RS_DDR   DDRB

/*! Display read/write (R/W) */
#define IO_DISPLAY_RW       IO_DISPLAY_RW
#define IO_DISPLAY_RW_PORT  PORTB
#define IO_DISPLAY_RW_BIT   3
#define IO_DISPLAY_RW_DDR   DDRB

/*! Display enable (E) */
#define IO_DISPLAY_EN       IO_DISPLAY_EN
#define IO_DISPLAY_EN_PORT  PORTB
#define IO_DISPLAY_EN_BIT   5
#define IO_DISPLAY_EN_DDR   DDRB

/*! Display chip select 1 (CS1) */
#define IO_DISPLAY_CS1       IO_DISPLAY_CS1
#define IO_DISPLAY_CS1_PORT  PORTC
#define IO_DISPLAY_CS1_BIT   2
#define IO_DISPLAY_CS1_DDR   DDRC

/*! Display chip select 2 (CS2) */
#define IO_DISPLAY_CS2       IO_DISPLAY_CS2
#define IO_DISPLAY_CS2_PORT  PORTC
#define IO_DISPLAY_CS2_BIT   3
#define IO_DISPLAY_CS2_DDR   DDRC
 
/*! Display reset (RST) */
#define IO_DISPLAY_RST       IO_DISPLAY_RST
#define IO_DISPLAY_RST_PIN   PINB
#define IO_DISPLAY_RST_PORT  PORTB
#define IO_DISPLAY_RST_BIT   2
#define IO_DISPLAY_RST_DDR   DDRB

/*! Display data port */
#define IO_DISPLAY_PORT  PORTD
#define IO_DISPLAY_PIN   PIND
#define IO_DISPLAY_DDR   DDRD



/*! Display illumination */
#define IO_DISP_LIGHT_PORT  PORTB
#define IO_DISP_LIGHT_BIT   1
#define IO_DISP_LIGHT_DDR   DDRB

